<?php
/**
 * laundryes back compat functionality
 *
 * Prevents laundryes from running on WordPress versions prior to 4.4,
 * since this theme is not meant to be backward compatible beyond that and
 * relies on many newer functions and markup changes introduced in 4.4.
 *
 * @package WordPress
 * @subpackage laundryes
 * @since laundryes 1.0
 */

/**
 * Prevent switching to laundryes on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since laundryes 1.0
 */
function laundryes_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );

	unset( $_GET['activated'] );

	add_action( 'admin_notices', 'laundryes_upgrade_notice' );
}
add_action( 'after_switch_theme', 'laundryes_switch_theme' );

/**
 * Adds a message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * laundryes on WordPress versions prior to 4.4.
 *
 * @since laundryes 1.0
 *
 * @global string $wp_version WordPress version.
 */
function laundryes_upgrade_notice() {
	$message = sprintf( esc_html__( 'Twenty Sixteen requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'laundryes' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevents the Customizer from being loaded on WordPress versions prior to 4.4.
 *
 * @since laundryes 1.0
 *
 * @global string $wp_version WordPress version.
 */
function laundryes_customize() {
	wp_die( sprintf( esc_html__( 'laundryes requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'laundryes' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'laundryes_customize' );

/**
 * Prevents the Theme Preview from being loaded on WordPress versions prior to 4.4.
 *
 * @since laundryes 1.0
 *
 * @global string $wp_version WordPress version.
 */
function laundryes_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( esc_html__( 'laundryes requires at least WordPress version 4.4. You are running version %s. Please upgrade and try again.', 'laundryes' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'laundryes_preview' );
